==> sylpheed-claws-gtk2_1.9.14.orig.tar.gz: sylpheed-claws-gtk2-1.9.14/src/matcher_parser_parse.h <==
/* A Bison parser, made by GNU Bison 2.0.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     MATCHER_ALL = 258,
     MATCHER_UNREAD = 259,
     MATCHER_NOT_UNREAD = 260,
     MATCHER_NEW = 261,
     MATCHER_NOT_NEW = 262,
     MATCHER_MARKED = 263,
     MATCHER_NOT_MARKED = 264,
     MATCHER_DELETED = 265,
     MATCHER_NOT_DELETED = 266,
     MATCHER_REPLIED = 267,
     MATCHER_NOT_REPLIED = 268,
     MATCHER_FORWARDED = 269,
     MATCHER_NOT_FORWARDED = 270,
     MATCHER_SUBJECT = 271,
     MATCHER_NOT_SUBJECT = 272,
     MATCHER_FROM = 273,
     MATCHER_NOT_FROM = 274,
     MATCHER_TO = 275,
     MATCHER_NOT_TO = 276,
     MATCHER_CC = 277,
     MATCHER_NOT_CC = 278,
     MATCHER_TO_OR_CC = 279,
     MATCHER_NOT_TO_AND_NOT_CC = 280,
     MATCHER_AGE_GREATER = 281,
     MATCHER_AGE_LOWER = 282,
     MATCHER_NEWSGROUPS = 283,
     MATCHER_NOT_NEWSGROUPS = 284,
     MATCHER_INREPLYTO = 285,
     MATCHER_NOT_INREPLYTO = 286,
     MATCHER_REFERENCES = 287,
     MATCHER_NOT_REFERENCES = 288,
     MATCHER_SCORE_GREATER = 289,
     MATCHER_SCORE_LOWER = 290,
     MATCHER_HEADER = 291,
     MATCHER_NOT_HEADER = 292,
     MATCHER_HEADERS_PART = 293,
     MATCHER_NOT_HEADERS_PART = 294,
     MATCHER_MESSAGE = 295,
     MATCHER_NOT_MESSAGE = 296,
     MATCHER_BODY_PART = 297,
     MATCHER_NOT_BODY_PART = 298,
     MATCHER_TEST = 299,
     MATCHER_NOT_TEST = 300,
     MATCHER_MATCHCASE = 301,
     MATCHER_MATCH = 302,
     MATCHER_REGEXPCASE = 303,
     MATCHER_REGEXP = 304,
     MATCHER_SCORE = 305,
     MATCHER_MOVE = 306,
     MATCHER_ANY_IN_ADDRESSBOOK = 307,
     MATCHER_ALL_IN_ADDRESSBOOK = 308,
     MATCHER_COPY = 309,
     MATCHER_DELETE = 310,
     MATCHER_MARK = 311,
     MATCHER_UNMARK = 312,
     MATCHER_LOCK = 313,
     MATCHER_UNLOCK = 314,
     MATCHER_EXECUTE = 315,
     MATCHER_MARK_AS_READ = 316,
     MATCHER_MARK_AS_UNREAD = 317,
     MATCHER_FORWARD = 318,
     MATCHER_FORWARD_AS_ATTACHMENT = 319,
     MATCHER_EOL = 320,
     MATCHER_STRING = 321,
     MATCHER_OR = 322,
     MATCHER_AND = 323,
     MATCHER_COLOR = 324,
     MATCHER_SCORE_EQUAL = 325,
     MATCHER_REDIRECT = 326,
     MATCHER_SIZE_GREATER = 327,
     MATCHER_SIZE_SMALLER = 328,
     MATCHER_SIZE_EQUAL = 329,
     MATCHER_LOCKED = 330,
     MATCHER_NOT_LOCKED = 331,
     MATCHER_PARTIAL = 332,
     MATCHER_NOT_PARTIAL = 333,
     MATCHER_COLORLABEL = 334,
     MATCHER_NOT_COLORLABEL = 335,
     MATCHER_IGNORE_THREAD = 336,
     MATCHER_NOT_IGNORE_THREAD = 337,
     MATCHER_CHANGE_SCORE = 338,
     MATCHER_SET_SCORE = 339,
     MATCHER_STOP = 340,
     MATCHER_HIDE = 341,
     MATCHER_RULENAME = 342,
     MATCHER_SECTION = 343,
     MATCHER_INTEGER = 344
   };
#endif
#define MATCHER_ALL 258
#define MATCHER_UNREAD 259
#define MATCHER_NOT_UNREAD 260
#define MATCHER_NEW 261
#define MATCHER_NOT_NEW 262
#define MATCHER_MARKED 263
#define MATCHER_NOT_MARKED 264
#define MATCHER_DELETED 265
#define MATCHER_NOT_DELETED 266
#define MATCHER_REPLIED 267
#define MATCHER_NOT_REPLIED 268
#define MATCHER_FORWARDED 269
#define MATCHER_NOT_FORWARDED 270
#define MATCHER_SUBJECT 271
#define MATCHER_NOT_SUBJECT 272
#define MATCHER_FROM 273
#define MATCHER_NOT_FROM 274
#define MATCHER_TO 275
#define MATCHER_NOT_TO 276
#define MATCHER_CC 277
#define MATCHER_NOT_CC 278
#define MATCHER_TO_OR_CC 279
#define MATCHER_NOT_TO_AND_NOT_CC 280
#define MATCHER_AGE_GREATER 281
#define MATCHER_AGE_LOWER 282
#define MATCHER_NEWSGROUPS 283
#define MATCHER_NOT_NEWSGROUPS 284
#define MATCHER_INREPLYTO 285
#define MATCHER_NOT_INREPLYTO 286
#define MATCHER_REFERENCES 287
#define MATCHER_NOT_REFERENCES 288
#define MATCHER_SCORE_GREATER 289
#define MATCHER_SCORE_LOWER 290
#define MATCHER_HEADER 291
#define MATCHER_NOT_HEADER 292
#define MATCHER_HEADERS_PART 293
#define MATCHER_NOT_HEADERS_PART 294
#define MATCHER_MESSAGE 295
#define MATCHER_NOT_MESSAGE 296
#define MATCHER_BODY_PART 297
#define MATCHER_NOT_BODY_PART 298
#define MATCHER_TEST 299
#define MATCHER_NOT_TEST 300
#define MATCHER_MATCHCASE 301
#define MATCHER_MATCH 302
#define MATCHER_REGEXPCASE 303
#define MATCHER_REGEXP 304
#define MATCHER_SCORE 305
#define MATCHER_MOVE 306
#define MATCHER_ANY_IN_ADDRESSBOOK 307
#define MATCHER_ALL_IN_ADDRESSBOOK 308
#define MATCHER_COPY 309
#define MATCHER_DELETE 310
#define MATCHER_MARK 311
#define MATCHER_UNMARK 312
#define MATCHER_LOCK 313
#define MATCHER_UNLOCK 314
#define MATCHER_EXECUTE 315
#define MATCHER_MARK_AS_READ 316
#define MATCHER_MARK_AS_UNREAD 317
#define MATCHER_FORWARD 318
#define MATCHER_FORWARD_AS_ATTACHMENT 319
#define MATCHER_EOL 320
#define MATCHER_STRING 321
#define MATCHER_OR 322
#define MATCHER_AND 323
#define MATCHER_COLOR 324
#define MATCHER_SCORE_EQUAL 325
#define MATCHER_REDIRECT 326
#define MATCHER_SIZE_GREATER 327
#define MATCHER_SIZE_SMALLER 328
#define MATCHER_SIZE_EQUAL 329
#define MATCHER_LOCKED 330
#define MATCHER_NOT_LOCKED 331
#define MATCHER_PARTIAL 332
#define MATCHER_NOT_PARTIAL 333
#define MATCHER_COLORLABEL 334
#define MATCHER_NOT_COLORLABEL 335
#define MATCHER_IGNORE_THREAD 336
#define MATCHER_NOT_IGNORE_THREAD 337
#define MATCHER_CHANGE_SCORE 338
#define MATCHER_SET_SCORE 339
#define MATCHER_STOP 340
#define MATCHER_HIDE 341
#define MATCHER_RULENAME 342
#define MATCHER_SECTION 343
#define MATCHER_INTEGER 344




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 239 "matcher_parser_parse.y"
typedef union YYSTYPE {
	char *str;
	int value;
} YYSTYPE;
/* Line 1318 of yacc.c.  */
#line 220 "matcher_parser_parse.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> sylpheed-claws-gtk2_2.1.1.orig.tar.gz: sylpheed-claws-gtk2-2.1.1/src/matcher_parser_parse.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     MATCHER_ALL = 258,
     MATCHER_UNREAD = 259,
     MATCHER_NOT_UNREAD = 260,
     MATCHER_NEW = 261,
     MATCHER_NOT_NEW = 262,
     MATCHER_MARKED = 263,
     MATCHER_NOT_MARKED = 264,
     MATCHER_DELETED = 265,
     MATCHER_NOT_DELETED = 266,
     MATCHER_REPLIED = 267,
     MATCHER_NOT_REPLIED = 268,
     MATCHER_FORWARDED = 269,
     MATCHER_NOT_FORWARDED = 270,
     MATCHER_SUBJECT = 271,
     MATCHER_NOT_SUBJECT = 272,
     MATCHER_FROM = 273,
     MATCHER_NOT_FROM = 274,
     MATCHER_TO = 275,
     MATCHER_NOT_TO = 276,
     MATCHER_CC = 277,
     MATCHER_NOT_CC = 278,
     MATCHER_TO_OR_CC = 279,
     MATCHER_NOT_TO_AND_NOT_CC = 280,
     MATCHER_AGE_GREATER = 281,
     MATCHER_AGE_LOWER = 282,
     MATCHER_NEWSGROUPS = 283,
     MATCHER_NOT_NEWSGROUPS = 284,
     MATCHER_INREPLYTO = 285,
     MATCHER_NOT_INREPLYTO = 286,
     MATCHER_REFERENCES = 287,
     MATCHER_NOT_REFERENCES = 288,
     MATCHER_SCORE_GREATER = 289,
     MATCHER_SCORE_LOWER = 290,
     MATCHER_HEADER = 291,
     MATCHER_NOT_HEADER = 292,
     MATCHER_HEADERS_PART = 293,
     MATCHER_NOT_HEADERS_PART = 294,
     MATCHER_MESSAGE = 295,
     MATCHER_NOT_MESSAGE = 296,
     MATCHER_BODY_PART = 297,
     MATCHER_NOT_BODY_PART = 298,
     MATCHER_TEST = 299,
     MATCHER_NOT_TEST = 300,
     MATCHER_MATCHCASE = 301,
     MATCHER_MATCH = 302,
     MATCHER_REGEXPCASE = 303,
     MATCHER_REGEXP = 304,
     MATCHER_SCORE = 305,
     MATCHER_MOVE = 306,
     MATCHER_ANY_IN_ADDRESSBOOK = 307,
     MATCHER_ALL_IN_ADDRESSBOOK = 308,
     MATCHER_COPY = 309,
     MATCHER_DELETE = 310,
     MATCHER_MARK = 311,
     MATCHER_UNMARK = 312,
     MATCHER_LOCK = 313,
     MATCHER_UNLOCK = 314,
     MATCHER_EXECUTE = 315,
     MATCHER_MARK_AS_READ = 316,
     MATCHER_MARK_AS_UNREAD = 317,
     MATCHER_FORWARD = 318,
     MATCHER_FORWARD_AS_ATTACHMENT = 319,
     MATCHER_EOL = 320,
     MATCHER_STRING = 321,
     MATCHER_OR = 322,
     MATCHER_AND = 323,
     MATCHER_COLOR = 324,
     MATCHER_SCORE_EQUAL = 325,
     MATCHER_REDIRECT = 326,
     MATCHER_SIZE_GREATER = 327,
     MATCHER_SIZE_SMALLER = 328,
     MATCHER_SIZE_EQUAL = 329,
     MATCHER_LOCKED = 330,
     MATCHER_NOT_LOCKED = 331,
     MATCHER_PARTIAL = 332,
     MATCHER_NOT_PARTIAL = 333,
     MATCHER_COLORLABEL = 334,
     MATCHER_NOT_COLORLABEL = 335,
     MATCHER_IGNORE_THREAD = 336,
     MATCHER_NOT_IGNORE_THREAD = 337,
     MATCHER_CHANGE_SCORE = 338,
     MATCHER_SET_SCORE = 339,
     MATCHER_STOP = 340,
     MATCHER_HIDE = 341,
     MATCHER_IGNORE = 342,
     MATCHER_RULENAME = 343,
     MATCHER_SECTION = 344,
     MATCHER_INTEGER = 345
   };
#endif
/* Tokens.  */
#define MATCHER_ALL 258
#define MATCHER_UNREAD 259
#define MATCHER_NOT_UNREAD 260
#define MATCHER_NEW 261
#define MATCHER_NOT_NEW 262
#define MATCHER_MARKED 263
#define MATCHER_NOT_MARKED 264
#define MATCHER_DELETED 265
#define MATCHER_NOT_DELETED 266
#define MATCHER_REPLIED 267
#define MATCHER_NOT_REPLIED 268
#define MATCHER_FORWARDED 269
#define MATCHER_NOT_FORWARDED 270
#define MATCHER_SUBJECT 271
#define MATCHER_NOT_SUBJECT 272
#define MATCHER_FROM 273
#define MATCHER_NOT_FROM 274
#define MATCHER_TO 275
#define MATCHER_NOT_TO 276
#define MATCHER_CC 277
#define MATCHER_NOT_CC 278
#define MATCHER_TO_OR_CC 279
#define MATCHER_NOT_TO_AND_NOT_CC 280
#define MATCHER_AGE_GREATER 281
#define MATCHER_AGE_LOWER 282
#define MATCHER_NEWSGROUPS 283
#define MATCHER_NOT_NEWSGROUPS 284
#define MATCHER_INREPLYTO 285
#define MATCHER_NOT_INREPLYTO 286
#define MATCHER_REFERENCES 287
#define MATCHER_NOT_REFERENCES 288
#define MATCHER_SCORE_GREATER 289
#define MATCHER_SCORE_LOWER 290
#define MATCHER_HEADER 291
#define MATCHER_NOT_HEADER 292
#define MATCHER_HEADERS_PART 293
#define MATCHER_NOT_HEADERS_PART 294
#define MATCHER_MESSAGE 295
#define MATCHER_NOT_MESSAGE 296
#define MATCHER_BODY_PART 297
#define MATCHER_NOT_BODY_PART 298
#define MATCHER_TEST 299
#define MATCHER_NOT_TEST 300
#define MATCHER_MATCHCASE 301
#define MATCHER_MATCH 302
#define MATCHER_REGEXPCASE 303
#define MATCHER_REGEXP 304
#define MATCHER_SCORE 305
#define MATCHER_MOVE 306
#define MATCHER_ANY_IN_ADDRESSBOOK 307
#define MATCHER_ALL_IN_ADDRESSBOOK 308
#define MATCHER_COPY 309
#define MATCHER_DELETE 310
#define MATCHER_MARK 311
#define MATCHER_UNMARK 312
#define MATCHER_LOCK 313
#define MATCHER_UNLOCK 314
#define MATCHER_EXECUTE 315
#define MATCHER_MARK_AS_READ 316
#define MATCHER_MARK_AS_UNREAD 317
#define MATCHER_FORWARD 318
#define MATCHER_FORWARD_AS_ATTACHMENT 319
#define MATCHER_EOL 320
#define MATCHER_STRING 321
#define MATCHER_OR 322
#define MATCHER_AND 323
#define MATCHER_COLOR 324
#define MATCHER_SCORE_EQUAL 325
#define MATCHER_REDIRECT 326
#define MATCHER_SIZE_GREATER 327
#define MATCHER_SIZE_SMALLER 328
#define MATCHER_SIZE_EQUAL 329
#define MATCHER_LOCKED 330
#define MATCHER_NOT_LOCKED 331
#define MATCHER_PARTIAL 332
#define MATCHER_NOT_PARTIAL 333
#define MATCHER_COLORLABEL 334
#define MATCHER_NOT_COLORLABEL 335
#define MATCHER_IGNORE_THREAD 336
#define MATCHER_NOT_IGNORE_THREAD 337
#define MATCHER_CHANGE_SCORE 338
#define MATCHER_SET_SCORE 339
#define MATCHER_STOP 340
#define MATCHER_HIDE 341
#define MATCHER_IGNORE 342
#define MATCHER_RULENAME 343
#define MATCHER_SECTION 344
#define MATCHER_INTEGER 345




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 245 "matcher_parser_parse.y"
typedef union YYSTYPE {
	char *str;
	int value;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 223 "matcher_parser_parse.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
